function [T,Mp, Mv] = momimp(filename)
%IMPORTFILE1 Import numeric data from a text file as column vectors.
%   [T,MX] = momimp(FILENAME) Reads data from text file
%   FILENAME for the default selection.

clc

%% Initialize variables.
delimiter = {') (','\t',' ',')','('};
if nargin<=2
    startRow = 4;
    endRow = inf;
end

%% Format for each line of text:
%   column1: double (%f)
%	column13: double (%f)
%   column15: double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%f %s %s %s %s %s %s %s %s %s %s %s %f %s %s %f %s %s %s %[^\n\r]';
format long
%% Open the text file.
fileID = fopen(filename,'r');

%% Read columns of data according to the format.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'EmptyValue', NaN, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'TextType', 'string', 'EmptyValue', NaN, 'HeaderLines', startRow(block)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Allocate imported array to column variable names
T = dataArray{:, 1}; %time
Mp = dataArray{:, 13};%pressure moment (z) from column 13
Mv = dataArray{:, 16};%viscous moment (z) from column 16


